#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
Libervia: a Salut à Toi frontend
Copyright (C) 2011  Jérôme Poisson <goffi@goffi.org>
Copyright (C) 2011  Adrien Vigneron <adrienvigneron@mailoo.org>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
"""

#This page manage subscription and new account creation
import pyjd # this is dummy in pyjs

from pyjamas.ui.SimplePanel import SimplePanel
from pyjamas.ui.VerticalPanel import VerticalPanel
from pyjamas.ui.HorizontalPanel import HorizontalPanel
from pyjamas.ui.TabPanel import TabPanel
from pyjamas.ui.TabBar import TabBar
from pyjamas.ui.Grid import Grid
from pyjamas.ui.PasswordTextBox import PasswordTextBox
from pyjamas.ui.TextBox import TextBox
from pyjamas.ui.FormPanel import FormPanel
from pyjamas.ui.Button import Button
from pyjamas.ui.Label import Label
from pyjamas.ui.CheckBox import CheckBox
from pyjamas.ui.PopupPanel import PopupPanel
from pyjamas.ui.Image import Image
from pyjamas.ui.Hidden import Hidden
from pyjamas import Window
from pyjamas.ui import HasAlignment
import re


class RegisterPanel(FormPanel):

    def __init__(self, callback):
        """
        @param callback: method to call if login successful
        """
        FormPanel.__init__(self)
        self.setSize('600px', '350px')
        self.callback = callback
        self.setMethod(FormPanel.METHOD_POST)
        main_panel = HorizontalPanel()
        main_panel.setStyleName('registerPanel_main')
        left_side = Image("register_left.png")
        main_panel.add(left_side)

        ##TabPanel##
        tab_bar = TabBar()
        tab_bar.setStyleName('registerPanel_tabs')
        self.right_side = TabPanel(tab_bar) 
        self.right_side.setStyleName('registerPanel_right_side')
        main_panel.add(self.right_side)
        main_panel.setCellWidth(self.right_side, '100%')
        

        ##Login tab##
        login_tab = SimplePanel()
        login_tab.setStyleName('registerPanel_content')
        login_vpanel = VerticalPanel()
        login_tab.setWidget(login_vpanel)
        
        
        self.warning_msg = Label()
        self.warning_msg.setVisible(False)
        self.warning_msg.setStyleName('formWarning')
        #login_vpanel.add(self.warning_msg)

        login_label = Label('Login:')
        self.login_box = TextBox()
        self.login_box.setName("login")
        login_pass_label = Label('Password:')
        login_pass_box = PasswordTextBox()
        login_pass_box.setName("login_password")
        login_vpanel.add(login_label)
        login_vpanel.add(self.login_box)
        login_vpanel.add(login_pass_label)
        login_vpanel.add(login_pass_box)
        login_but = Button("Log in", getattr(self, "onLogin"))
        login_but.setStyleName('button')
        login_but.addStyleName('red')
        login_vpanel.add(login_but)

        #The hidden submit_type field
        self.submit_type = Hidden('submit_type')
        login_vpanel.add(self.submit_type)

        
        ##Register tab##
        register_tab = SimplePanel()
        register_tab.setStyleName('registerPanel_content')
        register_vpanel = VerticalPanel()
        register_tab.setWidget(register_vpanel)
        
        register_login_label = Label('Login:')
        self.register_login_box = TextBox()
        self.register_login_box.setName("register_login")
        email_label = Label('E-mail:')
        self.email_box = TextBox()
        self.email_box.setName("email")
        register_pass_label = Label('Password:')
        self.register_pass_box = PasswordTextBox()
        self.register_pass_box.setName("register_password")
        register_vpanel.add(register_login_label)
        register_vpanel.add(self.register_login_box)
        register_vpanel.add(email_label)
        register_vpanel.add(self.email_box)
        register_vpanel.add(register_pass_label)
        register_vpanel.add(self.register_pass_box)
         
        register_but = Button("Register", getattr(self, "onRegister"))
        register_but.setStyleName('button')
        register_but.addStyleName('red')
        register_vpanel.add(register_but)
        
        self.right_side.add(login_tab, 'Login')
        self.right_side.add(register_tab, 'Register')
        self.right_side.selectTab(0)
        
        self.add(main_panel)
        self.addFormHandler(self)
        self.setAction('register_api/login')

    def onLogin(self, button):
        self.submit_type.setValue('login')
        self.submit()

    def onRegister(self, button):
        if not re.match(r'^[a-z0-9_-]+$',self.register_login_box.getText(), re.IGNORECASE):
            self.warning_msg.setText('Invaling login, valid characters are a-z A-Z 0-9 _ -')
            self.warning_msg.setVisible(True)
        elif not re.match(r'^.+@.+\..+', self.email_box.getText(), re.IGNORECASE):
            self.warning_msg.setText('Invaling email address')
            self.warning_msg.setVisible(True)
        else:
            self.warning_msg.setVisible(False)
            self.submit_type.setValue('register')
            self.submit()

    
    def onSubmit(self, event):
        pass

    def onSubmitComplete(self, event):
        result = event.getResults()
        if result == "AUTH ERROR":
            Window.alert('You login and/or password is incorrect. Please try again')
        elif result == "LOGGED":
            self.callback()
        elif result == "SESSION_ACTIVE":
            Window.alert('Session already active, this should not happen, please contact contact the author to fix it')
        elif result == "ALREADY EXISTS":
            self.warning_msg.setText('This login already exists, please choose an other one')
            self.warning_msg.setVisible(True)
        elif result == "REGISTRATION":
            self.warning_msg.setVisible(False)
            self.login_box.setText(self.register_login_box.getText())
            self.register_login_box.setText('')
            self.register_pass_box.setText('')
            self.email_box.setText('')
            self.right_side.selectTab(0)
            Window.alert('An email has been sent to you with your login informations\nPlease remember that this is ONLY A TECHNICAL DEMO')
        else:
            Window.alert('Submit error: %s' % result)

class RegisterBox(PopupPanel):

    def __init__(self, callback, *args,**kwargs):
        PopupPanel.__init__(self,*args,**kwargs)
        _form = RegisterPanel(callback)
        self.setWidget(_form)
    
    def onWindowResized(self, width, height):
        super(RegisterBox, self).onWindowResized(width, height)
        self.centerBox()

    def show(self):
        super(RegisterBox, self).show()
        self.centerBox()

